@@ -455,7 +455,6 @@ brasero_audio2cue_create_thread (gpointer data)
 	tracks = NULL;
 	brasero_job_get_tracks (data, &tracks);
 	for (; tracks; tracks = tracks->next) {
-		int isrc;
 		guint64 gap;
 		guint64 len;
 		gchar *string;
@@ -463,6 +462,7 @@ brasero_audio2cue_create_thread (gpointer data)
 		BraseroTrack *track;
 		const gchar *performer;
 		const gchar *songwriter;
+		const gchar *isrc;
 
 		track = tracks->data;
 
@@ -527,9 +527,9 @@ brasero_audio2cue_create_thread (gpointer data)
 			g_free (line);
 		}
 
-		isrc = brasero_track_tag_lookup_int (track, BRASERO_TRACK_STREAM_ISRC_TAG);
-		if (isrc > 0) {
-			line = g_strdup_printf ("\tISRC %i\n", isrc);
+		isrc = brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_ISRC_TAG);
+		if (isrc) {
+			line = g_strdup_printf ("\tISRC \"%s\"\n", isrc);
 			if (write (fd_out, line, strlen (line)) < 0) {
 				int err_saved = errno;
 				priv->error = g_error_new_literal (BRASERO_BURN_ERROR,
